"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils = require("tns-core-modules/utils/utils");
var app = require("tns-core-modules/application");
var permissions = require("nativescript-permissions");
var bluetooth = require("nativescript-bluetooth");
var MTSCRAEvent = com.magtek.mobile.android.mtlib.MTSCRAEvent;
var MTEMVEvent = com.magtek.mobile.android.mtlib.MTEMVEvent;
var MTDeviceConstants = com.magtek.mobile.android.mtlib.MTDeviceConstants;
var MTConnectionType = com.magtek.mobile.android.mtlib.MTConnectionType;
var MTSCRAConfig = com.magtek.mobile.android.mtlib.MTSCRAConfig;
var MTConnectionState = com.magtek.mobile.android.mtlib.MTConnectionState.Disconnected;
var MTConnectionStateConnected = com.magtek.mobile.android.mtlib.MTConnectionState.Connected;
var m_scra, m_scraHandler, m_connectionType, readCard, m_deviceAddress, m_audioConfigType, m_deviceName, led, m_headsetReceiver, m_bluetoothFoundReceiver, m_bluetoothDiscoveryReceiver;
var devices = Array();
var activity, callback, receiver, isConnectedTimer;
var b_device = null;
var ACCESS_COARSE_LOCATION_PERMISSION_REQUEST_CODE = 222;
var ACTION_REQUEST_ENABLE_BLUETOOTH_REQUEST_CODE = 223;
var ACTION_REQUEST_BLUETOOTH_DISCOVERABLE_REQUEST_CODE = 224;
var Cardreader = (function (_super) {
    __extends(Cardreader, _super);
    function Cardreader() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.scanTimeout = 4000;
        _this.hasStarted = false;
        _this.mScanning = false;
        _this.bluetoothManager = utils.ad
            .getApplicationContext()
            .getSystemService(android.content.Context.BLUETOOTH_SERVICE);
        _this.mBluetoothAdapter = _this.bluetoothManager.getAdapter();
        _this.EXTRAS_CONNECTION_TYPE_VALUE_AUDIO = "Audio";
        _this.EXTRAS_CONNECTION_TYPE_VALUE_BLE = "BLE";
        _this.EXTRAS_CONNECTION_TYPE_VALUE_BLE_EMV = "BLEEMV";
        _this.EXTRAS_CONNECTION_TYPE_VALUE_BLE_EMVT = "BLEEMVT";
        _this.EXTRAS_CONNECTION_TYPE_VALUE_BLUETOOTH = "Bluetooth";
        _this.EXTRAS_CONNECTION_TYPE_VALUE_USB = "USB";
        _this.EXTRAS_CONNECTION_TYPE_VALUE_SERIAL = "Serial";
        _this.EXTRAS_CONNECTION_TYPE = "CONNECTION_TYPE";
        _this.EXTRAS_DEVICE_NAME = "DEVICE_NAME";
        _this.EXTRAS_DEVICE_ADDRESS = "DEVICE_ADDRESS";
        _this.EXTRAS_AUDIO_CONFIG_TYPE = "AUDIO_CONFIG_TYPE";
        return _this;
    }
    Cardreader.prototype.stop = function () {
        this.hasStarted = false;
        if (m_connectionType == MTConnectionType.BLE && b_device != null) {
        }
        else {
            m_scra.closeDevice();
            app.android.unregisterBroadcastReceiver(m_headsetReceiver);
            m_scra.setConnectionRetry(false);
        }
    };
    Cardreader.prototype.start = function (cb, type) {
        callback = cb;
        console.log("Has started", this.hasStarted);
        if (this.hasStarted) {
            this.stop();
        }
        else {
            try {
                this.registerBroadcaster();
                this.hasStarted = true;
                m_scraHandler = new callbackHandler;
                m_scra = new com.magtek.mobile.android.mtlib.MTSCRA(this, m_scraHandler);
                this.startFromType(type);
            }
            catch (e) {
                console.log("Error on start", e);
            }
        }
    };
    Cardreader.prototype.say = function (msg) {
        console.dir(msg);
    };
    Cardreader.prototype.startFromType = function (type) {
        type = type.toUpperCase();
        console.log("Connection type:");
        switch (type) {
            case 'AUDIO':
                console.log("AUDIO");
                this.startAudio();
                break;
            case 'BLUETOOTH':
                console.log("BLUETOOTH");
                this.startBluetooth();
                break;
            default:
                console.log('Method not found');
                break;
        }
    };
    Cardreader.prototype.startBluetooth = function () {
        var _this = this;
        console.dir('isBluetoothOn', this.isBluetoothOn());
        console.dir("is bluetooth ble supported?", this.isBleSupported());
        this.enable().then(function (r) {
            _this.connectBluetoothDevice(true);
        });
    };
    Cardreader.prototype.isBleSupported = function () {
        var PackageManager = android.content.pm.PackageManager;
        return !app.android.context.getPackageManager().hasSystemFeature(PackageManager.FEATURE_BLUETOOTH_LE);
    };
    Cardreader.prototype.scanBluetoothDevices = function (enable) {
        if (enable) {
            try {
                this.mBluetoothAdapter.startDiscovery();
                console.log(this.mBluetoothAdapter.startDiscovery());
            }
            catch (e) {
                console.dir("Error while discovery", e);
            }
        }
        else {
            this.mScanning = false;
            this.mBluetoothAdapter.cancelDiscovery();
        }
    };
    Cardreader.prototype.enable = function () {
        return new Promise(function (resolve, reject) {
            try {
                var onBluetoothEnableResult_1 = function (args) {
                    if (args.requestCode === ACTION_REQUEST_ENABLE_BLUETOOTH_REQUEST_CODE) {
                        try {
                            app.android.off(app.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                            if (args.resultCode === android.app.Activity.RESULT_OK) {
                                resolve(true);
                            }
                            else {
                                resolve(false);
                            }
                        }
                        catch (ex) {
                            app.android.off(app.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                            reject(ex);
                            return;
                        }
                    }
                    else {
                        app.android.off(app.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                        resolve(false);
                        return;
                    }
                };
                app.android.on(app.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                var intent = new android.content.Intent(android.bluetooth.BluetoothAdapter.ACTION_REQUEST_ENABLE);
                var activity_1 = app.android.foregroundActivity || app.android.startActivity;
                activity_1.startActivityForResult(intent, ACTION_REQUEST_ENABLE_BLUETOOTH_REQUEST_CODE);
            }
            catch (ex) {
                reject(ex);
            }
        });
    };
    Cardreader.prototype.scanLeDevice = function (enable) {
        if (!this.mBluetoothAdapter.isEnabled()) {
            return;
        }
        if (enable) {
            try {
                var leCallback = new LeScanCallback;
                this.mBluetoothAdapter.getBluetoothLeScanner().startScan(leCallback);
            }
            catch (e) {
                console.dir("Can't start scan", e);
            }
        }
    };
    Cardreader.prototype.startAudio = function () {
        m_connectionType = MTConnectionType.Audio;
        m_scra.setConnectionType(m_connectionType);
        var config = this.getManualAudioConfig();
        m_scra.setDeviceConfiguration(config);
        m_scra.openDevice();
    };
    Cardreader.prototype.loadBluetooth = function () {
        var _this = this;
        console.log("Loading Bluetooth");
        return new Promise(function (resolve, reject) {
            bluetooth.isBluetoothEnabled().then(function (enabled) {
                if (b_device != null) {
                    _this.connectBluetoothDevice(b_device);
                }
                else if (enabled) {
                    bluetooth.startScanning({
                        serviceUUIDs: [MTDeviceConstants.UUID_SCRA_BLE_EMV_DEVICE_READER_SERVICE.toString()],
                        seconds: 4,
                        skipPermissionCheck: true,
                        onDiscovered: function (peripheral) {
                            if (peripheral.name != null) {
                                devices.push(peripheral);
                            }
                        }
                    }).then(function (r) {
                        console.log("scanning complete", r);
                        console.dir(devices);
                        var options = devices.map(function (device) {
                            return device.name;
                        });
                        action("Choose device", "Cancel", options)
                            .then(function (result) {
                            b_device = devices.find(function (device) {
                                return device.name == result;
                            });
                            if (b_device.hasOwnProperty('UUID')) {
                                _this.connectBluetoothDevice(b_device);
                            }
                        });
                    }, function (err) {
                        console.log("error while scanning: " + err);
                    });
                }
                else {
                }
            }).catch(function (e) {
                console.log("Error ", e);
            });
        });
    };
    Cardreader.prototype.connectBluetoothDevice = function (device) {
        m_scra.closeDevice();
        try {
            var activity_2 = app.android.foregroundActivity || app.android.startActivity;
            var intent = activity_2.getIntent();
            intent.putExtra(this.EXTRAS_CONNECTION_TYPE, this.EXTRAS_CONNECTION_TYPE_VALUE_BLE_EMV);
            intent.putExtra(this.EXTRAS_DEVICE_NAME, "eDynamo-B45B461");
            intent.putExtra(this.EXTRAS_DEVICE_ADDRESS, "34:03:DE:4A:06:08");
            activity_2.startActivity(intent);
        }
        catch (e) {
            console.log("Trying to do intents :)", e);
        }
        try {
            m_connectionType = MTConnectionType.BLEEMV;
            m_scra.setConnectionType(m_connectionType);
            m_scra.setConnectionTimeout(10000);
            m_scra.setAddress("34:03:DE:4A:06:08");
            m_scra.setConnectionRetry(true);
            m_scra.openDevice();
        }
        catch (e) {
            console.log("Error connecting", e);
        }
    };
    Cardreader.prototype.registerBroadcaster = function () {
        var _this = this;
        m_headsetReceiver = app.android.registerBroadcastReceiver(android.content.Intent.ACTION_HEADSET_PLUG, function (context, intent) {
            console.log("Audio Broadcast");
            var headSetState = intent.getIntExtra("state", 0);
            if (headSetState == 0) {
                if (m_scra.isDeviceConnected()) {
                    _this.hasStarted = false;
                    m_scra.closeDevice();
                }
            }
        });
    };
    Cardreader.prototype.getManualAudioConfig = function () {
        var config = "";
        m_scra.setConnectionRetry(true);
        try {
            var model = android.os.Build.MODEL.toUpperCase();
            console.log(model);
            if (model == "DROID RAZR" || model.toUpperCase() == "XT910") {
                config += "INPUT_SAMPLE_RATE_IN_HZ=48000,";
            }
            else if ((model == "DROID PRO") ||
                (model == "MB508") ||
                (model == "DROIDX") ||
                (model == "DROID2") ||
                (model == "MB525")) {
                config += "INPUT_SAMPLE_RATE_IN_HZ=32000,";
            }
            else if ((model == "GT-I9300") ||
                (model == "SPH-L710") ||
                (model == "SGH-T999") ||
                (model == "SCH-I535") ||
                (model == "SCH-R530") ||
                (model == "SAMSUNG-SGH-I747") ||
                (model == "M532") ||
                (model == "GT-N7100") ||
                (model == "GT-N7105") ||
                (model == "SAMSUNG-SGH-I317") ||
                (model == "SCH-I605") ||
                (model == "SCH-R950") ||
                (model == "SGH-T889") ||
                (model == "SPH-L900") ||
                (model == "GT-P3113")) {
                config += "INPUT_AUDIO_SOURCE=VRECOG,";
            }
            else if ((model == "XT907")) {
                config += "INPUT_WAVE_FORM=0,";
            }
            else {
                config += "INPUT_AUDIO_SOURCE=VRECOG,";
            }
        }
        catch (ex) {
            console.dir(ex);
        }
        console.dir("Configuration", config);
        return config;
    };
    Cardreader.prototype.requestUserPermissions = function () {
        return permissions.requestPermissions([
            android.Manifest.permission.RECORD_AUDIO,
            android.Manifest.permission.BLUETOOTH,
            android.Manifest.permission.BLUETOOTH_ADMIN,
            android.Manifest.permission.MODIFY_AUDIO_SETTINGS,
            android.Manifest.permission.ACCESS_COARSE_LOCATION,
            android.Manifest.permission.ACCESS_FINE_LOCATION,
        ]);
    };
    Cardreader.prototype.hasPermissions = function () {
        return new Promise(function (resolve, reject) {
            if (permissions.hasPermission(android.Manifest.permission.RECORD_AUDIO)
                && permissions.hasPermission(android.Manifest.permission.BLUETOOTH)
                && permissions.hasPermission(android.Manifest.permission.BLUETOOTH_ADMIN)
                && permissions.hasPermission(android.Manifest.permission.MODIFY_AUDIO_SETTINGS)
                && permissions.hasPermission(android.Manifest.permission.ACCESS_COARSE_LOCATION)
                && permissions.hasPermission(android.Manifest.permission.ACCESS_FINE_LOCATION)) {
                resolve(true);
            }
            else {
                reject(false);
            }
        });
    };
    return Cardreader;
}(android.app.Activity));
exports.Cardreader = Cardreader;
var callbackHandler = (function (_super) {
    __extends(callbackHandler, _super);
    function callbackHandler() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    callbackHandler.prototype.handleMessage = function (msg) {
        try {
            console.log("*** Callback " + msg.what);
            var state = msg.obj;
            switch (msg.what) {
                case MTSCRAEvent.OnDeviceConnectionStateChanged:
                    this.onDeviceStateChanged(state);
                    break;
                case MTSCRAEvent.OnCardDataStateChanged:
                    console.dir("OnCardDataStateChanged", state);
                    break;
                case MTSCRAEvent.OnDataReceived:
                    console.dir("OnDataReceived", state);
                    this.onCardDataReceived(state);
                    break;
                case MTSCRAEvent.OnDeviceResponse:
                    console.dir("OnDeviceResponse", state);
                    break;
                case MTSCRAEvent.OnDeviceBondingFailed:
                    console.dir("OnDeviceBondingFailed", state);
                    break;
                case MTEMVEvent.OnTransactionStatus:
                    console.dir("OnTransactionStatus", state);
                    break;
                case MTEMVEvent.OnDisplayMessageRequest:
                    console.dir("OnDisplayMessageRequest", state);
                    break;
                case MTEMVEvent.OnUserSelectionRequest:
                    console.dir("OnUserSelectionRequest", state);
                    break;
                case MTEMVEvent.OnARQCReceived:
                    console.dir("OnARQCReceived", state);
                    break;
                case MTEMVEvent.OnTransactionResult:
                    console.dir("OnTransactionResult", state);
                    break;
                case MTEMVEvent.OnEMVCommandResult:
                    console.dir("OnEMVCommandResult", state);
                    break;
                case MTEMVEvent.OnDeviceExtendedResponse:
                    console.dir("OnDeviceExtendedResponse", state);
                    break;
                default:
                    console.dir("not found?", state);
                    break;
            }
        }
        catch (ex) {
            console.log("Yey Exception", ex);
        }
        return true;
    };
    callbackHandler.prototype.onDeviceStateChanged = function (deviceState) {
        var type = deviceState.toString();
        this.setConnectionState(type);
        switch (type) {
            case "Disconnected":
                if (m_connectionType == MTConnectionType.Audio) {
                    this.restoreVolume();
                }
                break;
            case "Connected":
                if (m_connectionType == MTConnectionType.Audio) {
                    this.setVolumeToMax();
                }
                break;
            case "Error":
                console.log("Bahhh error...");
                break;
            case "Connecting":
                break;
            case "Disconnecting":
                break;
        }
    };
    callbackHandler.prototype.setConnectionState = function (state) {
        console.log("State", state);
        MTConnectionState = state;
    };
    callbackHandler.prototype.setVolumeToMax = function () {
        var context = android.content.Context;
        var am = app.android.context.getSystemService(context.AUDIO_SERVICE);
        am.getStreamMaxVolume(android.media.AudioManager.STREAM_MUSIC);
        console.log("Volume Set to max");
    };
    callbackHandler.prototype.restoreVolume = function () {
        var context = android.content.Context;
        var am = app.android.context.getSystemService(context.AUDIO_SERVICE);
        var currentVolume = am.getStreamVolume(android.media.AudioManager.STREAM_MUSIC);
        am.setStreamVolume(android.media.AudioManager.STREAM_MUSIC, currentVolume, 0);
        console.log("Volume Set to 0");
    };
    callbackHandler.prototype.onCardDataReceived = function (cardData) {
        console.dir(cardData);
        var bingo = com.magtek.mobile.android.mtlib.MTTLVCardData;
        console.dir(bingo);
    };
    return callbackHandler;
}(android.os.Handler));
var LeScanCallback = (function (_super) {
    __extends(LeScanCallback, _super);
    function LeScanCallback() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LeScanCallback.prototype.onLeScan = function (device, rssi, scanRecord) {
        console.dir(device, rssi, scanRecord);
    };
    LeScanCallback.prototype.parseUUIDs = function (uuid) {
        var uuidStr = uuid.toString();
        var pattern = java.util.regex.Pattern.compile('0000(.{4})-0000-1000-8000-00805f9b34fb', 2);
        var matcher = pattern.matcher(uuidStr);
        return matcher.matches() ? matcher.group(1) : uuidStr;
    };
    return LeScanCallback;
}(android.bluetooth.BluetoothAdapter.LeScanCallback));
var gattCallback = (function (_super) {
    __extends(gattCallback, _super);
    function gattCallback() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    gattCallback.prototype.onConnectionStateChange = function (gatt, status, newState) {
        console.dir("gatt", gatt);
        console.log("status (should be 0)", status);
        console.log("newState (should be 2)", newState);
        if (newState === android.bluetooth.BluetoothProfile.STATE_CONNECTED &&
            status === android.bluetooth.BluetoothGatt.GATT_SUCCESS) {
            console.log("Do discovery?");
            gatt.discoverServices();
        }
        else {
            console.log("im dead!");
        }
    };
    gattCallback.prototype.onServicesDiscovered = function (gatt, status) {
        try {
            console.log("Yellow?");
            var serviceUUID = MTDeviceConstants.UUID_SCRA_BLE_EMV_DEVICE_READER_SERVICE;
            console.dir("serviceUUID", MTDeviceConstants.UUID_SCRA_BLE_EMV_DEVICE_READER_SERVICE.toString());
            var bluetoothGattService = gatt.getService(serviceUUID);
            console.dir("bluetoothGattService", bluetoothGattService);
            var characteristic = bluetoothGattService.getCharacteristic(this.uuidToString('0508e6f8-ad82-898f-f843-e3410cb60201'));
            console.dir(characteristic);
        }
        catch (e) {
            console.log("Cant do this here?", e);
        }
    };
    gattCallback.prototype.uuidToString = function (uuid) {
        var uuidStr = uuid.toString();
        var pattern = java.util.regex.Pattern.compile('0000(.{4})-0000-1000-8000-00805f9b34fb', 2);
        var matcher = pattern.matcher(uuidStr);
        return matcher.matches() ? matcher.group(1) : uuidStr;
    };
    return gattCallback;
}(android.bluetooth.BluetoothGattCallback));
var CustomLeScanCallback = (function (_super) {
    __extends(CustomLeScanCallback, _super);
    function CustomLeScanCallback() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomLeScanCallback.prototype.onBatchScanResults = function (results) {
        if (results != null)
            this.processScanResult(results);
    };
    CustomLeScanCallback.prototype.onScanFailed = function (errorCode) {
        var errorMessage;
        if (errorCode === android.bluetooth.le.ScanCallback.SCAN_FAILED_ALREADY_STARTED) {
            errorMessage = 'Scan already started';
        }
        else if (errorCode === android.bluetooth.le.ScanCallback.SCAN_FAILED_APPLICATION_REGISTRATION_FAILED) {
            errorMessage = 'Application registration failed';
        }
        else if (errorCode === android.bluetooth.le.ScanCallback.SCAN_FAILED_FEATURE_UNSUPPORTED) {
            errorMessage = 'Feature unsupported';
        }
        else if (errorCode === android.bluetooth.le.ScanCallback.SCAN_FAILED_INTERNAL_ERROR) {
            errorMessage = 'Internal error';
        }
        else {
            errorMessage = 'Scan failed to start';
        }
        console.dir("errorMessage:", errorMessage);
    };
    CustomLeScanCallback.prototype.onScanResult = function (callbackType, result) {
        console.dir("onScanResult");
        console.dir("callbackType", callbackType);
        console.dir("result", result);
    };
    CustomLeScanCallback.prototype.processScanResult = function (result) {
        console.log("Chamo chamo?");
    };
    return CustomLeScanCallback;
}(android.bluetooth.le.ScanCallback));
;
//# sourceMappingURL=cardreader.android.backup.js.map